@@ -5,16 +5,12 @@ from .item.item_pip import fetch as _fetch_item_specs_pip
 from .order_capture import OrderCapture
 from .purchases import Purchases
 
-class fetch_items_specs:
-    # pyright: reportGeneralTypeIssues=false
-    def ingka(self):
-        return _fetch_items_specs_ingka(self)
-
-    def iows(self):
-        return _fetch_items_specs_iows(self)
-
-    def pip(self):
-        return _fetch_item_specs_pip(self)
+class _mock_fetch_items_specs:
+    def __init__(self) -> None:
+        self.ingka = _fetch_items_specs_ingka
+        self.iows = _fetch_items_specs_iows
+        self.pip =_fetch_item_specs_pip
 
+fetch_items_specs = _mock_fetch_items_specs()
 
 __all__ = ["Cart", "OrderCapture", "Purchases", "fetch_items_specs"]
